@@ -10,9 +10,6 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include "kcharselect_version.h"
 #include "kcharselectdia.h"
 
@@ -23,18 +20,6 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kcharselect"));
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    /**
-     * enable high dpi support
-     */
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("kcharselect"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kcharselectrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("kcharselectui.rc"));
-    migrate.migrate();
-#endif
-
     KAboutData aboutData(QStringLiteral("kcharselect"),
                          i18n("KCharSelect"),
                          QStringLiteral(KCHARSELECT_VERSION_STRING),
@@ -42,7 +27,7 @@ int main(int argc, char **argv)
                          KAboutLicense::GPL,
                          QString(),
                          i18n("A wrapper around the KCharSelect widget."),
-                         QStringLiteral("https://utils.kde.org/projects/kcharselect/"));
+                         QStringLiteral("https://apps.kde.org/kcharselect"));
 
     aboutData.addAuthor(i18n("Christoph Feck"), i18n("KF5 port and current maintainer"), QStringLiteral("cfeck@kde.org"));
     aboutData.addAuthor(i18n("Daniel Laidig"), i18n("Author and previous maintainer"), QStringLiteral("d.laidig@gmx.de"));
